@@ -5,21 +5,20 @@ calc_rblood2plasma <- function(chem.cas=NULL,
                               default.to.human=F,
                               species="Human")
 {
-   PK.physiology.data <- PK.physiology.data
+   physiology.data <- physiology.data
   parameters <- parameterize_schmitt(chem.cas=chem.cas,chem.name=chem.name,default.to.human=default.to.human,species=species)
   
-    if (!(species %in% colnames(PK.physiology.data)))
+    if (!(species %in% colnames(physiology.data)))
   {
-    if (toupper(species) %in% toupper(colnames(PK.physiology.data)))
+    if (toupper(species) %in% toupper(colnames(physiology.data)))
     {
-      PK.phys.species <- colnames(PK.physiology.data)[toupper(colnames(PK.physiology.data))==toupper(species)]
-      warning(paste(species,"coerced to",PK.phys.species,"for physiological data."))
+      phys.species <- colnames(physiology.data)[toupper(colnames(physiology.data))==toupper(species)]
     } else stop(paste("Physiological PK data for",species,"not found."))
-  } else PK.phys.species <- species
+  } else phys.species <- species
 
 # Load the physiological parameters for this species
-  this.phys.data <- PK.physiology.data[,PK.phys.species]
-  names(this.phys.data) <- PK.physiology.data[,1]
+  this.phys.data <- physiology.data[,phys.species]
+  names(this.phys.data) <- physiology.data[,1]
 
   hematocrit <- this.phys.data["Hematocrit"]
   
