@@ -17,7 +17,7 @@ CAS.checksum <- function(CAS.string)
 augment.table <- function(this.table,this.CAS,compound.name=NULL,this.property,value,species=NULL,reference,overwrite=F)
 {
 # In the table we create each word in most column names is capitalized:
-  exceptions <- c("Clint.pValue","logP","logMA","MW","CAS","CAS.Checksum","pKa_Donor","pKa_Accept","SMILES.desalt","DSSTox.GSID")
+  exceptions <- c("Clint.pValue","logP","logMA","logPwa","MW","CAS","CAS.Checksum","pKa_Donor","pKa_Accept","SMILES.desalt","DSSTox.GSID")
   if (tolower(this.property) %in% tolower(exceptions)) this.property <- exceptions[tolower(exceptions)==tolower(this.property)]
   else {
     this.property <- tolower(this.property)
@@ -25,7 +25,7 @@ augment.table <- function(this.table,this.CAS,compound.name=NULL,this.property,v
   }
 
   chem.id.cols<-c("Compound","CAS","CAS.Checksum","DSSTox.GSID","SMILES.desalt")
-  chem.phys.cols<-c("MW","logP","pKa_Donor","pKa_Accept","logMA")
+  chem.phys.cols<-c("MW","logP","logPwa","pKa_Donor","pKa_Accept","logMA")
   chem.invitro.cols <- c("Clint","Clint.pValue","Funbound.plasma","Fgutabs","Rblood2plasma")
                                      
   data.cols <- c("Reference","Species",chem.id.cols, chem.phys.cols,chem.invitro.cols)
@@ -126,7 +126,7 @@ add_chemtable <- function(new.table, data.list, current.table=NULL, reference=NU
                           species=NULL, overwrite=F)
 {
 # Let's make the capitalization consistent in data.list:
-  exceptions <- c("Clint.pValue","logP","logMA","MW","CAS","CAS.Checksum","pKa_Donor","pKa_Accept","SMILES.desalt","DSSTox.GSID")
+  exceptions <- c("Clint.pValue","logP","logPwa","logMA","MW","CAS","CAS.Checksum","pKa_Donor","pKa_Accept","SMILES.desalt","DSSTox.GSID")
   for (this.name in names(data.list))
   {
     if (tolower(this.name) %in% tolower(exceptions)) this.name <- exceptions[tolower(exceptions)==tolower(this.name)]
